# ============================================================================
# sk7SEG_74HC.py : MicroPython(ESP8266/ESP32)で７セグメントLEDシリアルドライバ
#      モジュール : https://akizukidenshi.com/catalog/g/gM-12642/
# ----------------------------------------------------------------------------
# VERSION DATE        BY                  CHANGE/COMMENT
# ----------------------------------------------------------------------------
# 1.10    2021-06-15  きむ茶工房(きむしげ) Create
# ============================================================================

class SevenSEG:
    """ ７セグメントLEDに数値を表示させるライブライ """
                 #  0   1   2   3   4   5   6   7   8   9   .   -  空白
    NumPattern = b'\x3F\x06\x5B\x4F\x66\x6D\x7D\x07\x7F\x6F\x80\x40\x00'

    def __init__(self, spi, latch):
        self.spi = spi
        self.latch = latch
        self.buff = bytearray(1)

    def NumOut(self, value):
        """
        ７セグメントLEDに指定した数値を表示させる
        value : 表示させる数値を文字列で指定します(例　"123" "15.6" "-2.7")。
        """
        _f = 0
        _p = value.find('.')
        # 小数点が指定された場合は成形する("15.6"を"1.56"や".5"を"0.5"等)
        if _p != -1:
            if _p == 1:
                _x = '.' + value[0] + value[2:]  # x.x～
            elif _p == 0:
                _x = '.0' + value[1:]             # 0.x～
            else:
                _x = value[_p-2] + '.' + value[_p-1] +  value[_p+1:]  # xx.x～
        else:
            _x = value
        self.latch.value(0)
        # 文字列だけ出力する
        for n in _x:
            if n == ' ':    # 空白
                self.buff[0] = self.NumPattern[12]
                self.spi.write(self.buff)
            elif n == '-':  # ーの記号
                self.buff[0] = self.NumPattern[11]
                self.spi.write(self.buff)
            elif n == '.':
                _f = 1
            else:           # 数値
                if _f == 1:
                    _f = 0
                    self.buff[0] = self.NumPattern[int(n)] | self.NumPattern[10]
                else:
                    self.buff[0] = self.NumPattern[int(n)]
                self.spi.write(self.buff)
        self.latch.value(1)  # ラッチする

def demo(value):
    """ ESP8266でのサンプルデモとなっています """
    from machine import Pin, SPI

    # SPIを初期化
    spi = SPI(1, baudrate=2000000, polarity=0, phase=0)
    # ピン４番(GPIO4)をSS(CS:LATCH)出力で割り付ける
    ss = Pin(4, Pin.OUT)

    seg = SevenSEG(spi, ss)
    seg.NumOut(value)

if __name__ == "__main__":
    demo(value)
